Module global_graph

Module global_graph 

Structs

AddResult
GlobalManifest
PrefixedGraph
RepoManifestEntry

Functions

check_cross_repo_guard
embed_global_graph
Generate dense embeddings for all nodes in the global graph and write to ~/.codesynapse/embeddings.json. Skipped (returns Ok(0)) when the model is not installed or when embeddings.json is already newer than global-graph.json (mtime-gated). Returns the number of nodes embedded.
global_add
global_add_force
global_list
global_remove
prefix_graph
prune_repo_from_graph